@@ -1,7 +1,9 @@
 <?php
-// Change_ldappass 1.3 (29th October 2002)
+// Change_ldappass 1.5 (May 15, 2003)
 //  
-// Copyright Simon Annetts 2000 - 2002. 
+// Copyright Simon Annetts 2000 - 2002. simon@ateb.co.uk 
+// PLEASE SEND QUESTIONS COMMENTS AND CHANGES TO MAINTAINOR.
+// New Maintainor: Raymond Ferguson foo@share-foo.com
 // 
 // This software may be used, modified and distributed freely
 // providing this copyright notice remains intact at the head 
@@ -14,7 +16,7 @@
 // wish to use this software you should first satisfy yourself that 
 // it meets your requirements.
 //
-// Email: simon@ateb.co.uk
+// Email: foo@share-foo.com (Ray Ferguson, Maintainor)
 //
 // Portions of code, ideas, suggestions and bug fixes have been posted by:
 //
@@ -26,16 +28,36 @@
 // Todd Lyons
 // Greg Schueler 
 // Beat
+// Georg Lehner (internationalization)
+// Ray Ferguson
 // 
 // Apologies if I've missed anyone :-)
 
-
-
-
-
    chdir ("..");
-   session_start();
+   define('SM_PATH','../');
 
+// include compatibility plugin
+if (defined('SM_PATH'))
+   include_once(SM_PATH . 'plugins/compatibility/functions.php');
+else if (file_exists('../plugins/compatibility/functions.php'))
+   include_once('../plugins/compatibility/functions.php');
+else if (file_exists('./plugins/compatibility/functions.php'))
+   include_once('./plugins/compatibility/functions.php');
+
+if (compatibility_check_sm_version(1, 3)) {
+   if (!isset($config_php))
+      include_once (SM_PATH . "config/config.php");
+   include_once(SM_PATH . 'include/validate.php');
+   if (!isset($strings_php))
+      include_once (SM_PATH . "functions/strings.php");
+   if (!isset($page_header))
+      include_once (SM_PATH . "functions/page_header.php");
+   if (!isset($imap_php))
+      include_once (SM_PATH . "functions/imap.php");
+   include_once (SM_PATH . "include/load_prefs.php");
+} else {
+   //session_start(); 
+   include_once("../src/validate.php");
    if (!isset($config_php))
       include_once ("../config/config.php");
    if (!isset($strings_php))
@@ -44,18 +66,29 @@
       include_once ("../functions/page_header.php");
    if (!isset($imap_php))
       include_once ("../functions/imap.php");
+   include_once ("../src/load_prefs.php");
+}
+
+function do_international() {
+   bindtextdomain('change_ldappass', '../plugins/change_ldappass/locale');
+   textdomain('change_ldappass');
+}
+
+function undo_international() {
+    bindtextdomain('squirrelmail', SM_PATH . 'locale');
+    textdomain('squirrelmail');
+}
 
    if ($_POST['plugin_change_ldappass'] != null) $Messages = change_ldappass_check();
- 
-    include_once ("../src/load_prefs.php");
    displayPageHeader($color, "None");
 
+do_international();
 ?>
 
 <br>
 <table width=95% align=center cellpadding=2 cellspacing=2 border=0>
 <tr><td bgcolor="<?php echo $color[0] ?>">
-   <center><b>Change Password</b></center>
+   <center><b><?php echo _("Change Password") ?></b></center>
 </td><?php
 
 if (isset($Messages) && count($Messages)) {
@@ -70,24 +103,25 @@ if (isset($Messages) && count($Messages)) {
     <form method=post action="<?php print $_SERVER['PHP_SELF'] ?>">
     <table>
       <tr>
-        <th align=right>Old Password:</th>
+        <th align=right><?php echo _("Old Password:")?></th>
         <td><input type=password name=cp_oldpass value=""  size=20></td>
       </tr>
       <tr>
-        <th align=right>New Password:</th>
+        <th align=right><?php echo _("New Password:")?></th>
         <td><input type=password name=cp_newpass value="" size=20></td>
       </tr>
       <tr>
-        <th align=right>Verify New Password:</th>
+        <th align=right><?php echo _("Verify New Password:")?></th>
         <td><input type=password name=cp_verify value="" size=20></td>
       </tr>
       <tr>
-        <td align=center colspan=2><input type=submit value="Submit" name="plugin_change_ldappass"></td>
+        <td align=center colspan=2><input type=submit value="<?php echo _("Change Password") ?>" name="plugin_change_ldappass"></td>
       </tr>
     </table>
 </td></tr>
 </tr></table>
 </body></html>
+<?php undo_international(); ?>
 <?php
 
 function change_ldappass_check($debug = 0) {
@@ -98,12 +132,13 @@ function change_ldappass_check($debug = 0) {
 	$username = $_SESSION['username'];
 
 	$Messages = array();
-
-	if ($cp_oldpass == "")	array_push($Messages, 'You must type in your old password.');
-	if ($cp_newpass == "") array_push($Messages, 'You must type in a new password.');
-	if ($cp_verify == "") array_push($Messages,'You must also type in your new password in the verify box.');
-	if ($cp_newpass != "" && $cp_verify != $cp_newpass) array_push($Messages,'Your new password doesn\'t match the verify password.');
+	do_international();
+	if ($cp_oldpass == "")	array_push($Messages, _("You must type in your old password."));
+	if ($cp_newpass == "") array_push($Messages, _("You must type in a new password."));
+	if ($cp_verify == "") array_push($Messages, _("You must also type in your new password in the verify box."));
+	if ($cp_newpass != "" && $cp_verify != $cp_newpass) array_push($Messages, _("Your new password doesn't match the verify password."));
 	if (!preg_match("/^[A-Za-z0-9\\%\^\*\(\)\-\_\+\=\[\]\{\}\:\@\#\~\,\.\? ]+$/",$cp_newpass)) array_push($Messages,'Passwords can only contain the following characters:<br>A-Z, a-z, 0-9, %^*()-_+=[]{}:@#~,.?');
+        undo_international();
 	if (count($Messages)) return $Messages;
 	return change_ldappass_go($debug);
 }
@@ -117,22 +152,23 @@ function change_ldappass_go($debug) {
 
 		include_once("../plugins/change_ldappass/config.php");
     $Messages = array();
-    if ($debug) array_push($Messages, "Connecting to LDAP Server");
+    do_international(); 
+    if ($debug) array_push($Messages, _("Connecting to LDAP Server"));
 
  		$ds=ldap_connect($ldap_server);
  		if (! $ds) {
-			array_push($Messages,'Can\'t connect to Directory Server, please try later!');
+			array_push($Messages, _("Can't connect to Directory Server, please try later!"));
 	 		return $Messages;
  		}
 		// first bind anonymously and try to determine the correct dn for the user with uid=$username
 		$r=ldap_bind($ds,"","");
 		$sr=ldap_search($ds,$ldap_base_dn,"($ldap_user_field=$username)",array("dn")); //search for uid
 		if (ldap_count_entries($ds,$sr)>1) {
-			array_push($Messages,'Duplicate login entries detected, cannot change password!');
+			array_push($Messages, _("Duplicate login entries detected, cannot change password!"));
 			return $Messages;
 		}
 		if (ldap_count_entries($ds,$sr)==0) {
-			array_push($Messages,'Your login account was not found in the LDAP database, cannot change password!');
+			array_push($Messages, _("Your login account was not found in the LDAP database, cannot change password!"));
 			return $Messages;
 		}
 		$info=ldap_get_entries($ds,$sr);
@@ -142,17 +178,17 @@ function change_ldappass_go($debug) {
 		// now rebind the the database as user or as root if required
 		if (! $ldap_bind_as_manager) {
 			if (! @ldap_bind($ds,$dn,$cp_oldpass)) { //if we can't bind as the user then the old passwd must be wrong
-				array_push($Messages,'Your old password is not correct.');
+				array_push($Messages, _("Your old password is not correct."));
 				return $Messages;
 			} else {
-				if ($debug) array_push($Messages,"Bind to database as $dn successful.");	
+				if ($debug) array_push($Messages, _("Bind to database as $dn successful."));	
 			}
 		} else {
 			if (! @ldap_bind($ds,$ldap_manager_dn,$ldap_manager_pw)) {
-				array_push($Messages,"Could not bind to the LDAP server as $ldap_manager_dn. Is the password correct?");
+				array_push($Messages, _("Could not bind to the LDAP server as $ldap_manager_dn. Is the password correct?"));
 				return $Messages;
 			} else {
-				if ($debug) array_push($Messages,"Bind to database as $ldap_manager_dn successful.");	
+				if ($debug) array_push($Messages, _("Bind to database as $ldap_manager_dn successful."));
 			}				
 		}
 		$sr=ldap_search($ds,$ldap_base_dn,"($ldap_user_field=$username)"); //check the db again, this time so we get the password field returned
@@ -181,15 +217,15 @@ function change_ldappass_go($debug) {
 				$stype="DES";		 						//sensible default if not detected
 				if ($pl>=34 and substr($lpass,0,3)=="$1$") $stype="MD5"; 
 				if ($pl>=34 and substr($lpass,0,3)=="$2$") $stype="BLOWFISH";	
-				if ($debug) array_push($Messages, "Password type is {crypt}, sub-type $stype");
+				if ($debug) array_push($Messages, _("Password type is {crypt}, sub-type $stype"));
 				$cpass=ldap_crypt_passwd($cp_oldpass,$lpass,$stype); //crypt up our old password so we can check it again
 				break;
 			case "{md5":
-				if ($debug) array_push($Messages, "Password type is {MD5}");
+				if ($debug) array_push($Messages, _("Password type is {MD5}"));
 				$cpass=ldap_md5_passwd($cp_oldpass);
 				break;
 			case "{sha":
-				if ($debug) array_push($Messages, "Password type is {SHA}");
+				if ($debug) array_push($Messages, _("Password type is {SHA}"));
 				$cpass=ldap_sha_passwd($cp_oldpass);
 				break;
       default:                        // Use plain text password
@@ -199,8 +235,8 @@ function change_ldappass_go($debug) {
 		}	
 		//now check again the stored password against the encrypted version of the supplied old password
 		if ($lpass != $cpass) {
-			array_push($Messages,"Your old password is not correct.");
-			if ($debug) array_push($Messages,"Stored Password: $lpass  Old Password: $cpass");
+			array_push($Messages, _("Your old password is not correct."));
+			if ($debug) array_push($Messages, _("Stored Password: $lpass  Old Password: $cpass"));
 			return $Messages;
 		}
 		//Make sure the new passwd generation uses the encryption method of the previous password
@@ -219,7 +255,7 @@ function change_ldappass_go($debug) {
       	$newpass=$cp_newpass;
         break;
 		}
-		if ($debug) array_push($Messages,"New Password: $newpass");
+		if ($debug) array_push($Messages, _("New Password: $newpass"));
 		$newinfo=array();
 		$newinfo[$ldap_password_field][0]=$newpass;
 		if (@ldap_modify($ds,$dn,$newinfo)) {
@@ -228,7 +264,7 @@ function change_ldappass_go($debug) {
 				$exe="echo \"$cp_oldpass\" |$smb_passwd -U $username -s \"$cp_newpass\" 2>&1";
 				if ($debug) array_push($Messages,$exe);
 				$r=exec($exe,$s);
-				if ($r=="Password changed for user $username") $smb=1;
+				if ($r==_("Password changed for user $username")) $smb=1;
 			} else {
 				$smb=1;
 			}
@@ -240,32 +276,34 @@ function change_ldappass_go($debug) {
 				$key = OneTimePadEncrypt($cp_newpass, $onetimepad);
 				$_COOKIES['key']=$key;
 				setcookie("key", $key, 0, $base_uri);
-				// Automatically forward back to the options screen if correct
+				// Give feedback if password change was successful.
 				if ($debug == 0) {
-					header("Location: $base_uri/src/options.php?plugin_change_ldappass=true");
+                                        array_push($Messages, _("Password changed successfully"));
+                                        return $Messages ;
 					exit(0);
 				}
 				return $Messages;
 			} else { //smbpasswd change failed so we must re sync the ldap password back to its original
 				$newinfo[$ldap_password_field][0]=$storedpass;
 				$r=ldap_modify($ds,$dn,$newinfo);  //change it back so  they're not out of sync.
-				array_push($Messages,'SMB Password change was not successful, so LDAP not changed!');
+				array_push($Messages, _("SMB Password change was not successful, so LDAP not changed!"));
 				return $Messages;
 			}
 		} else {
-			array_push($Messages,'LDAP Password change was not successful!');
+			array_push($Messages, _("LDAP Password change was not successful!"));
 			return $Messages;
 		}
 		@ldap_close($ds);
+		undo_international();
 }
 
 // Generate an unsalted SHA1 pw. This should work withNetscape messaging / directory server 4+ 
-function ldap_sha_password($clear_pw) {
+function ldap_sha_passwd($clear_pw) {
 	return base64_encode(mHash(MHASH_SHA1, $clear_pw));
 }
 
 // Generate an unsalted MD5 pw. This works fine with OpenLDAP.
-function ldap_md5_password($clear_pw) {
+function ldap_md5_passwd($clear_pw) {
 	return base64_encode(pack("H*", md5($clear_pw)));	
 }
 
